Crate rustfs_targets

Crate rustfs_targets 

Re-exports

pub use catalog::extension::OPS_DIAGNOSTICS_EXTENSION_API_VERSION;
pub use catalog::extension::OPS_PROFILER_EXTENSION_API_VERSION;
pub use catalog::extension::S3_HOOK_EXTENSION_API_VERSION;
pub use catalog::extension::TARGET_AUDIT_CAPABILITY;
pub use catalog::extension::TARGET_NOTIFY_CAPABILITY;
pub use catalog::extension::builtin_extension_schemas;
pub use catalog::extension::builtin_ops_diagnostics_contract;
pub use catalog::extension::builtin_ops_diagnostics_extension_schema;
pub use catalog::extension::builtin_ops_profiler_contract;
pub use catalog::extension::builtin_ops_profiler_extension_schema;
pub use catalog::extension::builtin_s3_hook_contract;
pub use catalog::extension::builtin_s3_hook_extension_schema;
pub use catalog::extension::builtin_target_extension_schemas;
pub use catalog::extension::target_marketplace_extension_schema;
pub use catalog::extension::target_runtime_boundary;
pub use config::LegacyTargetInstanceDescriptor;
pub use config::TargetInstanceSourceClass;
pub use config::TargetInstanceSourceHints;
pub use config::TargetPluginInstance;
pub use config::TargetPluginInstanceCompatDescriptor;
pub use config::TargetPluginInstanceRecord;
pub use config::normalize_legacy_target_instances;
pub use config::normalize_legacy_target_instances_from_env;
pub use config::normalize_target_plugin_instances;
pub use config::normalize_target_plugin_instances_from_env;
pub use config::try_normalize_target_plugin_instances;
pub use config::try_normalize_target_plugin_instances_from_env;
pub use control_plane::TargetPluginEnableState;
pub use control_plane::TargetPluginExternalAction;
pub use control_plane::TargetPluginExternalActionDecision;
pub use control_plane::TargetPluginExternalActionError;
pub use control_plane::TargetPluginExternalFlowGate;
pub use control_plane::TargetPluginExternalFlowGateStatus;
pub use control_plane::TargetPluginInstallState;
pub use control_plane::TargetPluginInstallation;
pub use control_plane::TargetPluginOperationalState;
pub use control_plane::TargetPluginRevision;
pub use control_plane::TargetPluginRuntimeState;
pub use control_plane::builtin_target_plugin_installation;
pub use control_plane::builtin_target_plugin_operational_state;
pub use control_plane::external_target_plugin_installation;
pub use control_plane::plan_external_target_plugin_action;
pub use control_plane::rollback_target_plugin_installation;
pub use control_plane::runtime_state_from_status_label;
pub use domain::TargetDomain;
pub use error::StoreError;
pub use error::TargetError;
pub use manifest::SUPPORTED_PLUGIN_API_COMPATIBILITY_VERSION;
pub use manifest::TargetPluginArtifactManifest;
pub use manifest::TargetPluginDistributionManifest;
pub use manifest::TargetPluginEntrypointKind;
pub use manifest::TargetPluginExternalRuntimeContract;
pub use manifest::TargetPluginManifest;
pub use manifest::TargetPluginMarketplaceManifest;
pub use manifest::TargetPluginPackaging;
pub use manifest::TargetPluginRuntimeTransport;
pub use manifest::builtin_target_marketplace_manifest;
pub use manifest::installable_target_marketplace_manifest;
pub use plugin::BuiltinTargetAdminDescriptor;
pub use plugin::BuiltinTargetDescriptor;
pub use plugin::PluginEvent;
pub use plugin::TargetAdminMetadata;
pub use plugin::TargetPluginDescriptor;
pub use plugin::TargetPluginRegistry;
pub use plugin::TargetRequestValidator;
pub use plugin::boxed_target;
pub use runtime::OpenedActivation;
pub use runtime::PreparedActivation;
pub use runtime::ReplayEvent;
pub use runtime::ReplayWorkerManager;
pub use runtime::RuntimeActivation;
pub use runtime::RuntimeStatusSnapshot;
pub use runtime::RuntimeTargetHealthReason;
pub use runtime::RuntimeTargetHealthSnapshot;
pub use runtime::RuntimeTargetHealthState;
pub use runtime::RuntimeTargetSnapshot;
pub use runtime::SharedTarget;
pub use runtime::TargetRuntimeManager;
pub use runtime::activate_targets_with_replay;
pub use runtime::adapter::BuiltinPluginRuntimeAdapter;
pub use runtime::adapter::PluginRuntimeAdapter;
pub use runtime::health_snapshots_for_targets;
pub use runtime::init_target_and_optionally_start_replay;
pub use runtime::ops_diagnostics::OpsDiagnosticsAccessDecision;
pub use runtime::ops_diagnostics::OpsDiagnosticsReadRequest;
pub use runtime::ops_diagnostics::OpsDiagnosticsRegistration;
pub use runtime::ops_diagnostics::OpsDiagnosticsRegistry;
pub use runtime::ops_diagnostics::OpsDiagnosticsRegistryError;
pub use runtime::ops_profiler::OpsProfilerAccessDecision;
pub use runtime::ops_profiler::OpsProfilerReadRequest;
pub use runtime::ops_profiler::OpsProfilerRegistration;
pub use runtime::ops_profiler::OpsProfilerRegistry;
pub use runtime::ops_profiler::OpsProfilerRegistryError;
pub use runtime::s3_hooks::S3HookContext;
pub use runtime::s3_hooks::S3HookDecision;
pub use runtime::s3_hooks::S3HookDispatchOutcome;
pub use runtime::s3_hooks::S3HookRegistration;
pub use runtime::s3_hooks::S3HookRegistry;
pub use runtime::s3_hooks::S3HookRegistryError;
pub use runtime::sidecar::SidecarPluginRuntime;
pub use runtime::sidecar::SidecarRuntimePolicy;
pub use runtime::sidecar::SidecarRuntimePolicyError;
pub use runtime::sidecar::SidecarRuntimeSafetyChecks;
pub use runtime::sidecar_protocol::SIDECAR_RUNTIME_PROTOCOL_VERSION;
pub use runtime::sidecar_protocol::SidecarHandshake;
pub use runtime::sidecar_protocol::SidecarPluginCapability;
pub use runtime::start_replay_worker;
pub use target::Target;
pub use target::TargetDeliverySnapshot;
pub use target::TargetHealth;
pub use target::TargetHealthReason;
pub use target::TargetHealthState;
pub use sys::user_agent::*;

Modules

arn
catalog
config
control_plane
domain
error
manifest
plugin
runtime
store
sys
target

Structs

Host
Host represents a network host with IP/name and port.
ParsedURL
URL is a wrapper around url::Url for custom handling.
TargetLog
Represents a log of events for sending to targets

Enums

EventName
Represents the type of event that occurs on the object. Based on AWS S3 event type and includes RustFS extension.
NetError
NetError represents errors that can occur in network operations.

Functions

check_amqp_broker_available
check_kafka_broker_available
check_mqtt_broker_available
Check if MQTT Broker is available
check_mqtt_broker_available_with_tls
check_mysql_server_available
Probes a MySQL server for connectivity.
check_nats_server_available
check_postgres_server_available
Probes a PostgreSQL server for connectivity and verifies the configured table is readable.
check_pulsar_broker_available
check_redis_server_available
extract_params_header
Extract parameters from hyper::HeaderMap, mainly header information.
extract_req_params
Extract request parameters from S3Request, mainly header information.
extract_req_params_headerDeprecated
Extract request parameters from hyper::HeaderMap, mainly header information. This function is useful when you have a raw HTTP request and need to extract parameters.
extract_resp_elements
Extract response elements from S3Response, mainly header information.
get_request_content_length
Get content-length from header information.
get_request_host
Get host from header information.
get_request_port
Get Port from header information. Priority:
get_request_referer
Get referer from header information.
get_request_user_agent
Get user-agent from header information.
is_conn_refused_err
is_conn_reset_err
is_network_or_host_down
parse_host
parse_host parses a string into a Host, with validation similar to Go’s ParseHost.
parse_http_url
parse_url
parse_url parses a string into a ParsedURL, with host validation and path cleaning.