pub struct PreparedActivation<E>where
E: PluginEvent,{ /* private fields */ }Expand description
Targets that have completed initialization but have not started replay workers yet. Keeping preparation dormant lets lifecycle orchestration stop the previous workers before the replacement workers are spawned.
Implementations
Sourceimpl<E> PreparedActivation<E>where
E: PluginEvent,
impl<E> PreparedActivation<E>where
E: PluginEvent,
pub fn failure_summary(&self) -> Option<String>
pub fn extend_creation_failures( &mut self, failures: impl IntoIterator<Item = String>, )